@@ -120,7 +120,7 @@ impl Error {
 
     /// Set the "more details" of this hRPC error.
     pub fn with_details(mut self, details: impl Into<Bytes>) -> Self {
-        self.more_details = details.into();
+        self.details = details.into();
         self
     }
 
@@ -135,18 +135,42 @@ impl Error {
         self.human_message = message.into();
         self
     }
+
+    pub(crate) fn invalid_hrpc_error(details: impl Into<Bytes>) -> Self {
+        Self {
+            human_message:
+                "the server error was an invalid hRPC error, check more_details field for the error"
+                    .to_string(),
+            identifier: "hrpcrs.invalid-hrpc-error".to_string(),
+            details: details.into(),
+        }
+    }
 }
 
-impl From<&'static str> for Error {
-    fn from(msg: &'static str) -> Self {
+impl<'a> From<&'a str> for Error {
+    fn from(msg: &'a str) -> Self {
         Error::default()
             .with_identifier(HrpcErrorIdentifier::InternalServerError)
             .with_message(msg)
     }
 }
 
-impl From<(&'static str, &'static str)> for Error {
-    fn from((id, msg): (&'static str, &'static str)) -> Self {
+impl<'a, 'b> From<(&'a str, &'b str)> for Error {
+    fn from((id, msg): (&'a str, &'b str)) -> Self {
+        Error::default().with_identifier(id).with_message(msg)
+    }
+}
+
+impl From<String> for Error {
+    fn from(msg: String) -> Self {
+        Error::default()
+            .with_identifier(HrpcErrorIdentifier::InternalServerError)
+            .with_message(msg)
+    }
+}
+
+impl<'a> From<(&'a str, String)> for Error {
+    fn from((id, msg): (&'a str, String)) -> Self {
         Error::default().with_identifier(id).with_message(msg)
     }
 }
